@@ -14,16 +14,16 @@ import (
 
 // Parse reads an OPML file and returns a SubcriptionList.
 func Parse(data io.Reader) (SubcriptionList, *errors.LocalizedError) {
-	feeds := new(opml)
+	opmlDocument := NewOPMLDocument()
 	decoder := xml.NewDecoder(data)
 	decoder.Entity = xml.HTMLEntity
 	decoder.Strict = false
 	decoder.CharsetReader = encoding.CharsetReader
 
-	err := decoder.Decode(feeds)
+	err := decoder.Decode(opmlDocument)
 	if err != nil {
 		return nil, errors.NewLocalizedError("Unable to parse OPML file: %q", err)
 	}
 
-	return feeds.Transform(), nil
+	return opmlDocument.GetSubscriptionList(), nil
 }
