@@ -16,7 +16,6 @@ var predefinedRules = map[string]string{
 	"framatube.org":          "nl2br,convert_text_link",
 	"happletea.com":          "add_image_title",
 	"imogenquest.net":        "add_image_title",
-	"invidio.us":             "add_invidious_video",
 	"lukesurl.com":           "add_image_title",
 	"medium.com":             "fix_medium_images",
 	"mercworks.net":          "add_image_title",
@@ -26,6 +25,7 @@ var predefinedRules = map[string]string{
 	"oglaf.com":              "add_image_title",
 	"optipess.com":           "add_image_title",
 	"peebleslab.com":         "add_image_title",
+	"quantamagazine.org":     `add_youtube_video_from_id, remove("h6:not(.byline,.post__title__kicker), #comments, .next-post__content, .footer__section, figure .outer--content, script")`,
 	"sentfromthemoon.com":    "add_image_title",
 	"thedoghousediaries.com": "add_image_title",
 	"treelobsters.com":       "add_image_title",
