@@ -12,6 +12,7 @@ import (
 	"strconv"
 	"strings"
 
+	"miniflux.app/config"
 	"miniflux.app/url"
 
 	"golang.org/x/net/html"
@@ -308,7 +309,6 @@ func isBlockedResource(src string) bool {
 
 func isValidIframeSource(baseURL, src string) bool {
 	whitelist := []string{
-		"https://invidio.us",
 		"//www.youtube.com",
 		"http://www.youtube.com",
 		"https://www.youtube.com",
@@ -334,6 +334,11 @@ func isValidIframeSource(baseURL, src string) bool {
 		return true
 	}
 
+	// allow iframe from custom invidious instance
+	if config.Opts != nil && config.Opts.InvidiousInstance() == url.Domain(src) {
+		return true
+	}
+
 	for _, prefix := range whitelist {
 		if strings.HasPrefix(src, prefix) {
 			return true
